Sequence

Struct Sequence 

pub struct Sequence(pub Number, pub Number);
A sequence, represented by the two starting values, which are later used to compute further values

Tuple Fields

0: Number1: Number

Implementations

Source

impl Sequence

pub fn new(sequence: impl Into<Self>) -> Self

Creates a new sequence with the given starting values

Examples
Sequence::new([1,1]);
pub fn fibonacci() -> Self

Returns the fibonacci sequence, represented as a Sequence struct

Examples
let sequence = Sequence::new([1, 1]);
let fib_sequence = Sequence::fibonacci();

assert_eq!(sequence, fib_sequence);
Examples found in repository?
examples/find_69.rs (line 4)
1fn main() {
2    let nth = 69;
3
4    let number = fibonacci_like::Sequence::fibonacci().calculate(nth);
5
6    println!("The \"{nth}\" number of the fibonacci sequence is:\n{number}");
7}
More examples
Hide additional examples
examples/get_arg.rs (line 14)
3fn main() {
4    let arg = std::env::args().nth(1).unwrap_or_else(|| {
5        println!("Please enter a number");
6        panic!();
7    });
8
9    let nth = usize::from_str(&arg).unwrap_or_else(|_| {
10        println!("Please pass a valid number");
11        panic!();
12    });
13
14    let number = fibonacci_like::Sequence::fibonacci().calculate(nth);
15
16    println!("The \"{nth}\" number of the fibonacci sequence is:\n{number}");
17}
examples/find_arg.rs (line 16)
5fn main() {
6    let arg = std::env::args().nth(1).unwrap_or_else(|| {
7        println!("Please enter a number");
8        panic!();
9    });
10
11    let nth = i128::from_str(&arg).unwrap_or_else(|_| {
12        println!("Please pass a valid number");
13        panic!();
14    });
15
16    let number = fibonacci_like::Sequence::fibonacci()
17        .find(nth.into_number())
18        .unwrap();
19
20    println!("The \"{nth}\" number of the fibonacci sequence is:\n{number}");
21}
pub fn calculate(self, n: usize) -> Number

Calculate the nth term of the sequence

Examples
let sequence = Sequence::fibonacci();
let nth_term = sequence.calculate(3);

assert_eq!(nth_term, 2_i128.into_number());
Examples found in repository?
examples/find_69.rs (line 4)
1fn main() {
2    let nth = 69;
3
4    let number = fibonacci_like::Sequence::fibonacci().calculate(nth);
5
6    println!("The \"{nth}\" number of the fibonacci sequence is:\n{number}");
7}
More examples
Hide additional examples
examples/get_arg.rs (line 14)
3fn main() {
4    let arg = std::env::args().nth(1).unwrap_or_else(|| {
5        println!("Please enter a number");
6        panic!();
7    });
8
9    let nth = usize::from_str(&arg).unwrap_or_else(|_| {
10        println!("Please pass a valid number");
11        panic!();
12    });
13
14    let number = fibonacci_like::Sequence::fibonacci().calculate(nth);
15
16    println!("The \"{nth}\" number of the fibonacci sequence is:\n{number}");
17}
pub fn find(self, number: Number) -> Result<usize, FindError>

Find the given number’s position in the sequence

Examples
let fifteenth = 610.into_number();

let fib = Sequence::fibonacci();

assert_eq!(fib.find(fifteenth).unwrap(), 15);
Examples found in repository?
examples/find_arg.rs (line 17)
5fn main() {
6    let arg = std::env::args().nth(1).unwrap_or_else(|| {
7        println!("Please enter a number");
8        panic!();
9    });
10
11    let nth = i128::from_str(&arg).unwrap_or_else(|_| {
12        println!("Please pass a valid number");
13        panic!();
14    });
15
16    let number = fibonacci_like::Sequence::fibonacci()
17        .find(nth.into_number())
18        .unwrap();
19
20    println!("The \"{nth}\" number of the fibonacci sequence is:\n{number}");
21}